
# Type: inverse


indicates that any instance of d s r implies that there is also an instance of r s' d

URI: [meta:inverse](https://w3id.org/biolink/biolinkml/meta/inverse)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [SlotDefinition](SlotDefinition.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | owl:inverseOf |

